div.caption {
	margin: auto;
	border: 1px solid #ccc;
	padding: 5px;
}

div.right {margin-right: 0;}
div.left  { margin-left: 0;}

div.caption img {
	margin: 0;
	padding:0;
}

div.caption p {
	margin: 5px 0 0 0;
	padding: 5px;
	border-top: 1px #ddd dotted;
	font-size: .9em;
	text-align: center;
}

.image_without_caption {
	margin: auto;
	border: 1px solid #ccc;
	padding: 5px;
}
